@@ -39,6 +39,10 @@ package.
    (I added the -v option for od and removed 'const')
 */
 
+/* Note: I read there're various implementations of a tool called
+   'bin2c' to do the job.  This might come in handy if there's ever
+   need to do that again. */
+
 const char vgasys_fon[] = {
 0x4d,0x5a,0x0d,0x01,0x01,0x00,0x00,0x00,0x04,0x00,0x00,0x00,0xff,0xff,0x00,0x00,
 0xb8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
